@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.0.2';
+our $VERSION = 'v2.1.0';
 
 
 # Possible types of current directory:
@@ -44,7 +44,7 @@ Narada - framework for ease deploy and support microservice projects
 
 =head1 VERSION
 
-This document describes Narada version v2.0.2
+This document describes Narada version v2.1.0
 
 
 =head1 SYNOPSIS
@@ -658,13 +658,7 @@ Shell patterns (one per line) for files/dirs which shouldn't be included
 in backup. Must contain at least these lines:
 
     ./.backup/*         to avoid recursively including old backups in new
-    ./.lock             to avoid unlocking while restoring from backup
-    ./.lock.new         to avoid project in locked state after restore
-                        from backup
-    ./.lock.bg          to avoid unlocking while restoring from backup
-    ./.lock.service     to avoid unlocking while restoring from backup
-                        (this file is from narada-plugin-runit, but same
-                        should apply to similar files from other plugins)
+    ./.lock*            to avoid unlocking while restoring from backup
     ./tmp/*             to conform to Narada interface and not include
                         temporary files in backups
 
@@ -687,7 +681,13 @@ backup at all (even scheme).
 
 =item C<var/mysql/>
 
-Contains files with last database dump (usually made while last backup).
+Contain files with last database dump (usually made while last backup).
+
+=item C<var/use/>
+
+Keeps current used/unused state recorded by last run of C<narada-setup-*>
+and C<narada-*-services> tools. It will be used by L<narada-restore> to
+setup project after full restore.
 
 =item C<.backup/full.tar>
 
@@ -1018,6 +1018,8 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 CONTRIBUTORS
 
+Nikita Savin E<lt>asdfgroup@gmail.comE<gt>
+
 Nick Levchenko E<lt>project129@yandex.ruE<gt>
 
 
