@@ -13,6 +13,7 @@ use Path::Tiny qw( cwd path tempdir tempfile );
 use File::Copy::Recursive qw( dircopy );
 use POSIX qw(locale_h); BEGIN { setlocale(LC_MESSAGES,'en_US.UTF-8') } # avoid UTF-8 in $!
 use FindBin;
+use Config;
 
 
 my $proj    = tempdir('narada.project.XXXXXX');
@@ -23,7 +24,7 @@ sub DESTROY { system('narada-setup-cron --clean >/dev/null 2>&1'); chdir q{/} }
 sub guard   { ($_[0], $guard) = ($guard, undef) }
 
 my $work        = cwd();
-$ENV{PATH}      = "$work/blib/script:$work/bin:$ENV{PATH}";
+$ENV{PATH}      = "$work/blib/script:$work/bin:".path($Config{perlpath})->dirname.":$ENV{PATH}";
 $ENV{PERL5LIB}  = "$work/blib:$work/lib".($ENV{PERL5LIB} ? ":$ENV{PERL5LIB}" : q{});
 
 dircopy("$work/t/.release", "$proj/.release")       or die "dircopy: $!";
